@@ -2,7 +2,7 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.GL.Core30
--- Copyright   :  (c) Sven Panne 2017
+-- Copyright   :  (c) Sven Panne 2018
 -- License     :  BSD3
 --
 -- Maintainer  :  Sven Panne <svenpanne@gmail.com>
@@ -431,6 +431,7 @@ module Graphics.GL.Core30 (
   pattern GL_HINT_BIT,
   pattern GL_INCR,
   pattern GL_INCR_WRAP,
+  pattern GL_INDEX,
   pattern GL_INDEX_ARRAY,
   pattern GL_INDEX_ARRAY_BUFFER_BINDING,
   pattern GL_INDEX_ARRAY_POINTER,
@@ -1034,9 +1035,11 @@ module Graphics.GL.Core30 (
   pattern GL_TEXTURE_GREEN_TYPE,
   pattern GL_TEXTURE_HEIGHT,
   pattern GL_TEXTURE_INTENSITY_SIZE,
+  pattern GL_TEXTURE_INTENSITY_TYPE,
   pattern GL_TEXTURE_INTERNAL_FORMAT,
   pattern GL_TEXTURE_LOD_BIAS,
   pattern GL_TEXTURE_LUMINANCE_SIZE,
+  pattern GL_TEXTURE_LUMINANCE_TYPE,
   pattern GL_TEXTURE_MAG_FILTER,
   pattern GL_TEXTURE_MATRIX,
   pattern GL_TEXTURE_MAX_LEVEL,
