@@ -2,7 +2,7 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.GL.EXT.TextureFilterMinmax
--- Copyright   :  (c) Sven Panne 2017
+-- Copyright   :  (c) Sven Panne 2018
 -- License     :  BSD3
 --
 -- Maintainer  :  Sven Panne <svenpanne@gmail.com>
@@ -16,16 +16,9 @@ module Graphics.GL.EXT.TextureFilterMinmax (
   glGetEXTTextureFilterMinmax,
   gl_EXT_texture_filter_minmax,
   -- * Enums
-  pattern GL_EFFECTIVE_RASTER_SAMPLES_EXT,
-  pattern GL_MAX_RASTER_SAMPLES_EXT,
-  pattern GL_MULTISAMPLE_RASTERIZATION_ALLOWED_EXT,
-  pattern GL_RASTER_FIXED_SAMPLE_LOCATIONS_EXT,
-  pattern GL_RASTER_MULTISAMPLE_EXT,
-  pattern GL_RASTER_SAMPLES_EXT,
-  -- * Functions
-  glRasterSamplesEXT
+  pattern GL_TEXTURE_REDUCTION_MODE_EXT,
+  pattern GL_WEIGHTED_AVERAGE_EXT
 ) where
 
 import Graphics.GL.ExtensionPredicates
 import Graphics.GL.Tokens
-import Graphics.GL.Functions
