@@ -1,7 +1,7 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.GL.INTEL
--- Copyright   :  (c) Sven Panne 2017
+-- Copyright   :  (c) Sven Panne 2018
 -- License     :  BSD3
 --
 -- Maintainer  :  Sven Panne <svenpanne@gmail.com>
@@ -13,6 +13,7 @@
 --------------------------------------------------------------------------------
 
 module Graphics.GL.INTEL (
+  module Graphics.GL.INTEL.BlackholeRender,
   module Graphics.GL.INTEL.ConservativeRasterization,
   module Graphics.GL.INTEL.FramebufferCmaa,
   module Graphics.GL.INTEL.MapTexture,
@@ -20,6 +21,7 @@ module Graphics.GL.INTEL (
   module Graphics.GL.INTEL.PerformanceQuery
 ) where
 
+import Graphics.GL.INTEL.BlackholeRender
 import Graphics.GL.INTEL.ConservativeRasterization
 import Graphics.GL.INTEL.FramebufferCmaa
 import Graphics.GL.INTEL.MapTexture
